"""
unit tests
"""
from kawhi import say_hello


def test_say_hello_no_params():
    """ no arguments test """
    assert (say_hello()) == "Hello, Kawhi!"


def test_say_hello_with_param():
    """ no arguments test """
    assert (say_hello("John")) == "Hello, Kawhi - This is John."



"""
Kawhi package test pypi package publishing
"""
from get_jokes import get_joke


def say_hello(name=None):
    """ dummy function"""
    if name:
        return f"Hello, Kawhi - This is {name}."

    return "Hello, Kawhi!"


def kawhi_joke(search_term=None):
    """
    Gets a joke and appends a Kawhi laugh to it.
    """

    if search_term:
        # TODO get joke about a specific topic
        pass

    returned_joke = get_joke()

    if not returned_joke["success"]:
        return "That's all folks!"

    # return joke:
    return f"{returned_joke['joke']}\n\nAha....ha, ha, ha, ha"


print(kawhi_joke())



"""
setup module
"""
from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="Kawhi",
    version="0.0.3",
    description="A package inspired by Kawhi Leonard of the Toronto Raptors",
    py_modules=["kawhi"],
    package_dir={"": "src"},
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=["requests"],
    long_description=long_description,
    long_description_content_type="text/markdown",
)
